@@ -16,9 +16,11 @@ func ReportError(format string, args ...interface{}) otto.Value {
 func init() {
 	// TODO: refactor this in packages
 
+	plugin.Defines["mkdirAll"] = mkdirAll
 	plugin.Defines["readDir"] = readDir
 	plugin.Defines["readFile"] = readFile
 	plugin.Defines["writeFile"] = writeFile
+	plugin.Defines["appendFile"] = appendFile
 
 	plugin.Defines["log"] = flog
 	plugin.Defines["log_debug"] = log_debug
@@ -27,10 +29,16 @@ func init() {
 	plugin.Defines["log_error"] = log_error
 	plugin.Defines["log_fatal"] = log_fatal
 
+	plugin.Defines["Crypto"] = map[string]interface{}{
+		"sha1": cryptoSha1,
+	}
+
 	plugin.Defines["btoa"] = btoa
 	plugin.Defines["atob"] = atob
 	plugin.Defines["gzipCompress"] = gzipCompress
 	plugin.Defines["gzipDecompress"] = gzipDecompress
+	plugin.Defines["textEncode"] = textEncode
+	plugin.Defines["textDecode"] = textDecode
 
 	plugin.Defines["httpRequest"] = httpRequest
 	plugin.Defines["http"] = httpPackage{}
