@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"io"
 
-	"github.com/bettercap/bettercap/session"
+	"github.com/bettercap/bettercap/v2/session"
 	"github.com/evilsocket/islazy/tui"
 )
 
